'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _ = require('../../');

var duplicate = function duplicate(oldFilePath, template, newPath, name, req) {
  var isUpdate = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : false;

  var p = new Promise(function (resolve, reject) {
    _.Hooks.instance.trigger('beforeDuplicate', oldFilePath, template, newPath, name, req, isUpdate);

    var json = {};
    var revisions = [];
    if (typeof oldFilePath !== 'undefined' && oldFilePath !== null) {
      var files = _.Manager.instance.getList();
      var fileWithoutExtension = oldFilePath.replace('.' + _.config.files.templates.extension, '');

      var doc = null;
      Array.prototype.forEach.call(files, function (file) {
        if (file.path.indexOf(fileWithoutExtension) > -1) {
          doc = file;
        }
      });

      if (typeof doc.revisions !== 'undefined' && doc.revisions !== null) {
        revisions = doc.revisions;

        if (typeof revisions !== 'undefined' && revisions !== null && typeof revisions[0] !== 'undefined' && revisions[0] !== null) {
          json = _.FileParser.getJson(revisions[0].path);
        }
      }

      delete json.abe_meta;
    }

    if (isUpdate) {
      _.Hooks.instance.trigger('beforeUpdate', json, oldFilePath, template, newPath, name, req, isUpdate);
      _.FileParser.deleteFile(oldFilePath);
    }
    _.Hooks.instance.trigger('afterDuplicate', json, oldFilePath, template, newPath, name, req, isUpdate);

    var pCreate = (0, _.abeCreate)(template, newPath, name, req, json, isUpdate ? false : true);
    pCreate.then(function (resSave) {
      resolve(resSave);
    }, function () {
      reject();
    }).catch(function (e) {
      console.error('[ERROR] abe-duplicate.js', e);
      reject();
    });
  });

  return p;
};

exports.default = duplicate;