'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _ = require('../../');

var duplicate = function duplicate(oldFilePath, template, newPath, name, req) {
  var isUpdate = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : false;

  var p = new Promise(function (resolve, reject) {
    _.Hooks.instance.trigger('beforeDuplicate', oldFilePath, template, newPath, name, req, isUpdate);

    var json = {};
    var revisions = [];
    if (oldFilePath != null) {
      var files = _.Manager.instance.getList();
      var fileWithoutExtension = oldFilePath.replace('.' + _.config.files.templates.extension, '');

      var doc = null;
      Array.prototype.forEach.call(files, function (file) {
        if (file.path.indexOf(fileWithoutExtension) > -1) {
          doc = file;
        }
      });

      if (doc.revisions != null) {
        revisions = doc.revisions;

        if (revisions != null && revisions[0] != null) {
          json = _.cmsData.file.get(revisions[0].path);
        }
      }

      delete json.abe_meta;
    }

    if (isUpdate) {
      _.Hooks.instance.trigger('beforeUpdate', json, oldFilePath, template, newPath, name, req, isUpdate);
      _.cmsOperations.remove.remove(oldFilePath);
    }
    _.Hooks.instance.trigger('afterDuplicate', json, oldFilePath, template, newPath, name, req, isUpdate);

    var pCreate = _.cmsOperations.create(template, newPath, name, req, json, isUpdate ? false : true);
    pCreate.then(function (resSave) {
      resolve(resSave);
    }, function () {
      reject();
    }).catch(function (e) {
      console.error('[ERROR] abe-duplicate.js', e);
      reject();
    });
  });

  return p;
};

exports.default = duplicate;