'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _fsExtra = require('fs-extra');

var _fsExtra2 = _interopRequireDefault(_fsExtra);

var _child_process = require('child_process');

var _cli = require('../../cli');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var traverseFileSystem = function traverseFileSystem(currentPath, arr) {
  var res = [];
  var files = _fsExtra2.default.readdirSync(currentPath);
  for (var i in files) {
    var currentFile = currentPath + '/' + files[i];
    var stats = _fsExtra2.default.statSync(currentFile);
    if (stats.isFile()) {
      if (currentFile.indexOf(_cli.config.files.templates.extension) > -1) {
        res.push(currentFile);
      }
    } else if (stats.isDirectory()) {
      res = res.concat(traverseFileSystem(currentFile));
    }
  }
  return res;
};

var findTemplates = function findTemplates(templatesPath) {
  var p = new Promise(function (resolve, reject) {
    var templatesList = traverseFileSystem(templatesPath);
    resolve(templatesList);
  });

  return p;
};

/**
 * Get columns and where.left ids of a select statement
 *
 * select title, image from ../ where template=""
 *
 * return [title, image, template]
 * 
 * @param  {Array} templatesList ["article.html", "other.html"]
 * @return {Promise}
 */

var recurseWhereVariables = function recurseWhereVariables(where) {
  var ar = [];

  // console.log('* * * * * * * * * * * * * * * * * * * * * * * * * * * * *')
  // console.log('where', where.left)
  switch (where.operator) {
    case 'AND':
      var arLeft = recurseWhereVariables(where.left);
      var arRight = recurseWhereVariables(where.right);
      return arLeft.concat(arRight);
      break;
    case 'OR':
      var arLeft = recurseWhereVariables(where.left);
      var arRight = recurseWhereVariables(where.right);
      return arLeft.concat(arRight);
      break;
    case 'IN':
      break;
    case 'NOT IN':
      break;
    default:
      return [where.left.column];
      break;
  }

  return ar;
};

var findRequestColumns = function findRequestColumns(templatesList) {
  var whereKeysCheck = {};
  var whereKeys = [];
  var p = new Promise(function (resolve, reject) {
    var util = new _cli.Util();
    Array.prototype.forEach.call(templatesList, function (file) {
      var template = _fsExtra2.default.readFileSync(file, 'utf8');
      var matches = util.dataRequest(template);

      Array.prototype.forEach.call(matches, function (match) {
        var obj = _cli.Util.getAllAttributes(match[0], {});
        obj = _cli.Util.sanitizeSourceAttribute(obj, {});

        var type = _cli.Sql.getSourceType(obj.sourceString);

        switch (type) {
          case 'request':
            var request = _cli.Sql.handleSqlRequest(obj.sourceString, {});
            if (typeof request.columns !== 'undefined' && request.columns !== null) {
              Array.prototype.forEach.call(request.columns, function (column) {
                whereKeys.push(column);
              });
            }
            if (typeof request.where !== 'undefined' && request.where !== null) {
              whereKeys = whereKeys.concat(recurseWhereVariables(request.where));
            }
        }
      });
    });
    whereKeys = whereKeys.filter(function (item, pos) {
      return whereKeys.indexOf(item) == pos;
    });
    resolve(whereKeys);
  });

  return p;
};

var getSelectTemplateKeys = function getSelectTemplateKeys(templatesPath) {
  var p = new Promise(function (resolve, reject) {
    findTemplates(templatesPath).then(function (templatesList) {

      findRequestColumns(templatesList).then(function (whereKeys) {
        resolve(whereKeys);
      }, function () {
        console.log('findRequestColumns reject');
        reject();
      }).catch(function (e) {
        console.error('getSelectTemplateKeys', e);
        reject();
      });
    }, function () {
      console.log('findTemplates reject');
      reject();
    }).catch(function (e) {
      console.error('getSelectTemplateKeys', e);
      reject();
    });
  });

  return p;
};

exports.default = getSelectTemplateKeys;