'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _fsExtra = require('fs-extra');

var _fsExtra2 = _interopRequireDefault(_fsExtra);

var _mkdirp = require('mkdirp');

var _mkdirp2 = _interopRequireDefault(_mkdirp);

var _limax = require('limax');

var _limax2 = _interopRequireDefault(_limax);

var _cli = require('../../cli');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var route = function route(req, res, next) {
  _cli.Hooks.instance.trigger('beforeRoute', req, res, next);
  if (typeof res._header !== 'undefined' && res._header !== null) return;

  var resp = { success: 1 };
  var filePath;
  var folderWebPath = '/' + _cli.config.upload.image;
  folderWebPath = _cli.Hooks.instance.trigger('beforeSaveImage', folderWebPath, req);
  var folderFilePath = _path2.default.join(_cli.config.root, _cli.config.publish.url, folderWebPath);
  _mkdirp2.default.sync(folderFilePath);
  req.pipe(req.busboy);
  var finished = false;
  req.busboy.on('file', function (fieldname, file, filename, encoding, mimetype) {
    var ext = _path2.default.extname(filename);
    var filenameNoExt = _path2.default.basename(filename, ext);
    var randID = '-' + ((1 + Math.random()) * 0x100000 | 0).toString(16).substring(2);
    var slug = (0, _limax2.default)(filenameNoExt, { separateNumbers: false }) + randID + ext;

    filePath = _path2.default.join(folderFilePath, slug);
    resp['filePath'] = _path2.default.join(folderWebPath, slug);

    var returnErr = function returnErr(msg) {
      file.resume();
      res.set('Content-Type', 'application/json');
      res.send(JSON.stringify({ error: 1, response: msg }));
    };

    file.on('limit', function () {
      returnErr('file is too big');
    });

    if (mimetype !== 'image/jpeg' && mimetype !== 'image/png' && mimetype !== 'image/svg+xml' && mimetype !== 'video/mp4') {
      returnErr('unauthorized file');
    } else if (ext !== '.jpg' && ext !== '.jpeg' && ext !== '.png' && ext !== '.svg' && ext !== '.mp4') {
      returnErr('not a valid asset');
    }

    var fstream = _fsExtra2.default.createWriteStream(filePath);

    fstream.on('finish', function () {
      if (/\.(jpg|png|gif|svg)/.test(filePath)) {
        resp = _cli.Hooks.instance.trigger('afterSaveImage', resp, req);
      }
      // Waiting until the entire request has been fully processed
      if (finished) {
        res.set('Content-Type', 'application/json');
        res.send(JSON.stringify(resp));
      }
    });

    file.pipe(fstream);
  });
  req.busboy.on('finish', function () {
    finished = true;
  });
};

exports.default = route;